pub struct EdgeMappedMany {
pub graph: Graph,
pub edge_maps: Vec<Vec<Option<EdgeId>>>,
}Expand description
A graph produced by an operator on many graphs, together with one edge
map per operand (see Graph::union_many_map and
Graph::intersection_many_map).
Fields
graph: GraphThe resulting graph.
edge_maps: Vec<Vec<Option<EdgeId>>>edge_maps[i][e] is the id, in graph, of edge e
of the i-th operand, or None if that edge has no image.