pub struct InducedSubgraph {
pub graph: Graph,
pub map: Vec<Option<VertexId>>,
pub invmap: Vec<VertexId>,
}Expand description
An induced subgraph together with the correspondence between its
vertices and the vertices of the original graph (see
Graph::induced_subgraph_map).
Fields
graph: GraphThe induced subgraph.
map: Vec<Option<VertexId>>map[v] is the id in graph of the original vertex
v, or None if v was not selected. Its length is the vertex
count of the original graph.
invmap: Vec<VertexId>invmap[w] is the original id of vertex w of the subgraph. Its
length is the vertex count of the subgraph.